# Saranphat Roungkitrakran

Hello Guy, I will show you about how to use Madhava series to find number near π number. So I will explain this module used formula

```sh
π/4 = sigma(-1)^n/(2n+1)....
```

### How to install 

If you already installed python.You can use command prompt or python shell and use command 'pip'

```sh
pip install madhavapi
```

Alright. After installed my module , you can use my module now.

How to use 
- Open your python project and write by following this script
```sh
from madhavapi import Madhava

test = madhava(50)

```

### Contract us

You can contract me by following list:

| Topic | Link |
| ------ | ------ |
| E-mail |Gungungungundam@hotmail.com |
| not complete react project | https://tahpnaras.netlify.app |

### And I will come back in the future
